@@ -25,12 +25,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QFuture>
 #include <QFutureWatcher>
 #include <QtConcurrentRun>
+#include <QApplication>
+#include <QDebug>
 
 // KDE
-#include <KApplication>
-#include <KDebug>
-#include <kdialogjobuidelegate.h>
-#include <KLocale>
+#include <KDialogJobUiDelegate>
+#include <KLocalizedString>
 
 // Local
 
@@ -47,7 +47,7 @@ DocumentJob::DocumentJob()
 , d(new DocumentJobPrivate)
 {
     KDialogJobUiDelegate* delegate = new KDialogJobUiDelegate;
-    delegate->setWindow(KApplication::kApplication()->activeWindow());
+    delegate->setWindow(qApp->activeWindow());
     delegate->setAutoErrorHandlingEnabled(true);
     setUiDelegate(delegate);
 }
@@ -91,5 +91,3 @@ void ThreadedDocumentJob::doStart()
 }
 
 } // namespace
-
-#include <documentjob.moc>
